@@ -3,6 +3,7 @@ use vrp_core::models::problem::{ActivityCost, Actor};
 use vrp_core::models::solution::Activity;
 
 /// Uses costs only for vehicle ignoring costs of driver.
+#[derive(Default)]
 pub struct OnlyVehicleActivityCost {}
 
 impl ActivityCost for OnlyVehicleActivityCost {
@@ -13,9 +14,3 @@ impl ActivityCost for OnlyVehicleActivityCost {
         waiting * actor.vehicle.costs.per_waiting_time + service * actor.vehicle.costs.per_service_time
     }
 }
-
-impl Default for OnlyVehicleActivityCost {
-    fn default() -> Self {
-        Self {}
-    }
-}
