@@ -118,6 +118,10 @@ pub struct Job {
     /// Job group: jobs of the same group are assigned to the same tour or unassigned.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub group: Option<String>,
+
+    /// A compatibility group: jobs with different compatibility cannot be assigned to the same tour.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub compatibility: Option<String>,
 }
 
 // region Clustering
@@ -591,11 +595,6 @@ pub struct BalanceOptions {
     /// favor of another objective.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub threshold: Option<f64>,
-
-    /// A balancing tolerance specifies how much balance values should differ in order
-    /// to be considered as not-equal.
-    #[serde(skip_serializing_if = "Option::is_none")]
-    pub tolerance: Option<f64>,
 }
 
 // endregion
