@@ -1,10 +1,12 @@
+use crate::core::prelude::Solver;
 use crate::format::problem::*;
 use crate::format::solution::*;
 use crate::format_time;
 use crate::helpers::assert_vehicle_agnostic;
 use crate::helpers::*;
 use std::sync::Arc;
-use vrp_core::solver::Builder;
+use vrp_core::construction::heuristics::InsertionContext;
+use vrp_core::solver::create_default_config_builder;
 use vrp_core::utils::Environment;
 
 #[test]
@@ -180,10 +182,14 @@ fn can_use_init_solution_with_dispatch() {
     let core_problem = Arc::new((problem.clone(), vec![matrix]).read_pragmatic().unwrap());
     let core_solution = to_core_solution(&init_solution, core_problem.clone(), environment.random.clone()).unwrap();
 
-    let (core_solution, _, metrics) = Builder::new(core_problem.clone(), environment)
+    let (core_solution, _, metrics) = create_default_config_builder(core_problem.clone(), environment.clone())
         .with_max_generations(Some(100))
-        .with_init_solutions(vec![core_solution], None)
+        .with_init_solutions(
+            vec![InsertionContext::new_from_solution(core_problem.clone(), (core_solution, None), environment)],
+            None,
+        )
         .build()
+        .map(|config| Solver::new(core_problem.clone(), config))
         .unwrap_or_else(|err| panic!("cannot build solver: {}", err))
         .solve()
         .unwrap_or_else(|err| panic!("cannot solve the problem: {}", err));
