@@ -11,7 +11,7 @@ fn can_have_unassigned_due_to_missing_vehicle_skill() {
                 vec![1., 0.],
                 all_of_skills(vec!["unique_skill".to_string()]),
             )],
-            relations: Option::None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![create_default_vehicle("vehicle_without_skill")],
@@ -30,7 +30,7 @@ fn can_have_unassigned_due_to_missing_vehicle_skill() {
                 cost: 0.,
                 distance: 0,
                 duration: 0,
-                times: Timing { driving: 0, serving: 0, waiting: 0, break_time: 0 },
+                times: Timing { driving: 0, serving: 0, ..Timing::default() },
             },
             tours: vec![],
             unassigned: Some(vec![UnassignedJob {
