@@ -78,6 +78,7 @@ mod single {
                     create_pickup_job("job5", vec![5., 0.]),
                 ],
                 relations,
+                ..create_empty_plan()
             },
             fleet: Fleet {
                 vehicles: vec![VehicleType {
@@ -118,7 +119,7 @@ mod single {
                 cost: 51.,
                 distance: 16,
                 duration: 25,
-                times: Timing { driving: 16, serving: 9, waiting: 0, break_time: 2 },
+                times: Timing { driving: 16, serving: 9, break_time: 2, ..Timing::default() },
             },
             tours: vec![
                 VehicleTour {
@@ -149,6 +150,7 @@ mod single {
                                 departure: "1970-01-01T00:00:06Z".to_string(),
                             },
                             distance: 2,
+                            parking: None,
                             load: vec![0],
                             activities: vec![
                                 Activity {
@@ -157,6 +159,7 @@ mod single {
                                     location: None,
                                     time: None,
                                     job_tag: None,
+                                    commute: None,
                                 },
                                 Activity {
                                     job_id: "break".to_string(),
@@ -164,6 +167,7 @@ mod single {
                                     location: None,
                                     time: None,
                                     job_tag: None,
+                                    commute: None,
                                 },
                             ],
                         },
@@ -212,7 +216,7 @@ mod single {
                         cost: 51.,
                         distance: 16,
                         duration: 25,
-                        times: Timing { driving: 16, serving: 9, waiting: 0, break_time: 2 },
+                        times: Timing { driving: 16, serving: 9, break_time: 2, ..Timing::default() },
                     },
                 },
                 VehicleTour {
@@ -225,9 +229,9 @@ mod single {
             ],
             ..create_empty_solution()
         };
+        let ctx = CheckerContext::new(create_example_problem(), problem, None, solution).unwrap();
 
-        let result =
-            check_relations(&CheckerContext::new(create_example_problem(), problem, None, solution)).map_err(|_| ());
+        let result = check_relations(&ctx).map_err(|_| ());
 
         assert_eq!(result, expected_result);
     }
