@@ -3,10 +3,10 @@ use crate::format::problem::reader::ProblemProperties;
 use crate::helpers::create_empty_insertion_context;
 use crate::helpers::create_empty_problem;
 use std::sync::Arc;
-use vrp_core::algorithms::nsga2::MultiObjective;
 use vrp_core::construction::constraints::TOTAL_VALUE_KEY;
 use vrp_core::construction::constraints::{ConstraintPipeline, TOUR_ORDER_KEY};
 use vrp_core::construction::heuristics::InsertionContext;
+use vrp_core::rosomaxa::prelude::MultiObjective;
 
 fn create_problem_props() -> ProblemProperties {
     ProblemProperties {
